@@ -17,12 +17,17 @@ struct dccwindow
 {
    GtkWidget *window;
    GtkWidget *list;
-   gint selected;
 };
 
 struct dcc_send
 {
    struct session *sess;
-   char *nick;
+   char nick[64];
    GtkWidget *freq;
 };
+
+struct dcc_chat
+{
+   char linebuf[1024];
+   int pos;
+};
