@@ -1,8 +1,7 @@
 struct serverentry
 {
-   char used;
-   char unused;
-   struct serverentry *next;
+   char unused[2];
+   void *unused_pointer;
    long port;
    char channel[86];
    char server[100];
