@@ -1,13 +1,13 @@
 /*
  * All colors start with \003 followed by a color number 0-15.
- * 
+ *
  * To revert to default color "\003 " is used (a space after \003).
- * 
+ *
  * \002 can be used to turn bold on and off.
  */
 
-//#define STARTON "\0034\003 \0034\003 " // BitchX VERSION
-//#define STARTOFF "\0033\003 \0033\003 " // BitchX VERSION
+/*#define STARTON "\0034\003 \0034\003 "
+#define STARTOFF "\0033\003 \0033\003 "*/
 
 #define STARTON "\0034*\003 *\0034*\003 "
 #define STARTOFF "\0033*\003 *\0033*\003 "
@@ -17,3 +17,5 @@
 #define CHANNEL_MSG_FROM_USER "\0036<\003 %s\0036> \003 %s\n"
 #define CHANNEL_MSG_WITH_NICK "\0032<\002\0038%s\002\0032> \003 %s\n"
 #define CHANNEL_MSG "\0032<\003 %s\0032> \003 %s\n"
+#define CHANNEL_MSG_COLOR "<\003%d%s\003 > %s\n"
+#define ACTION_TEXT_COLOR "* \003%d%s\003  %s\n"
