@@ -2,6 +2,6 @@ struct user
 {
    struct user *next;
    char user[64];
-   char op;
-   char voice;
+   int op:1;
+   int voice:1;
 };
